@@ -32,7 +32,6 @@
 
 #include <QAction>
 #include <QApplication>
-#include <QDir>
 #include <QHBoxLayout>
 #include <QLabel>
 #include <QWidget>
@@ -86,7 +85,6 @@ Terminal::Terminal(QWidget* parent) : QObject(parent)
         disableOffendingPartActions();
 
         m_terminalInterface = qobject_cast<TerminalInterface*>(m_part);
-        if (m_terminalInterface) m_terminalInterface->showShellInDir(QDir::homePath());
     }
     else
         displayKPartLoadError();
@@ -169,7 +167,7 @@ void Terminal::displayKPartLoadError()
 
     QLabel* icon = new QLabel(widget);
     icon->setMargin(10);
-    icon->setPixmap(QIcon(QStringLiteral("dialog-warning")).pixmap(QSize(48, 48)));
+    icon->setPixmap(QIcon::fromTheme(QStringLiteral("dialog-warning")).pixmap(QSize(48, 48)));
     icon->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
 
     QHBoxLayout* layout = new QHBoxLayout(widget);
